pub struct ReplicationSnapshot {
pub format_version: u16,
pub last_index: u64,
pub records: Vec<ReplicationSnapshotRecord>,
pub checksum: String,
}Expand description
Integrity-protected portable image of a replication log.
Fields
format_version: u16Snapshot encoding version.
last_index: u64One-based index of the final record.
records: Vec<ReplicationSnapshotRecord>Replication records in log order.
checksum: StringSHA-256 checksum over version, index, sequences, and payloads.
Implementations
Sourceimpl ReplicationSnapshot
impl ReplicationSnapshot
Sourcepub fn try_from_records(
records: impl IntoIterator<Item = (u64, Vec<u8>)>,
) -> SyncResult<Self>
pub fn try_from_records( records: impl IntoIterator<Item = (u64, Vec<u8>)>, ) -> SyncResult<Self>
Creates a validated snapshot while taking ownership of every payload.
Payload allocations are moved into the snapshot instead of cloned. The same record-count, record-size, sequence-uniqueness and checksum contracts used by durable replication logs are applied.
Sourcepub fn validate(&self) -> SyncResult<()>
pub fn validate(&self) -> SyncResult<()>
Validates this snapshot without cloning record payloads.