SyncReceiverState

Struct SyncReceiverState 

pub struct SyncReceiverState { /* private fields */ }
In-memory receiver state for follower sync endpoint.

Implementations

Source

impl SyncReceiverState

pub fn new( replication_log: Arc<Mutex<Box<dyn ReplicationLog + Send>>>, checkpoint_store: Arc<dyn SyncCheckpointStore>, ) -> Self

Creates receiver state backed by a replication log and checkpoint store.

pub fn with_local_identity(self, local_identity: CoreIdentity) -> Self

Configures the distributed identity used to validate v1 sync envelopes.

pub fn replication_log(&self) -> Arc<Mutex<Box<dyn ReplicationLog + Send>>>

Returns a shared handle to the receiver’s replication log.

pub fn apply_sync_message( &self, message: &SyncMessage, ) -> SyncResult<SyncReceiveAck>

Validates and idempotently applies one already-authenticated batch.

pub fn apply_sync_envelope( &self, envelope: &SyncEnvelopeV1, ) -> SyncResult<SyncReceiveAck>

Validates a decoded wire envelope before applying its replication batch.