Sync contracts for roles, peer metadata, transport, election, and replication.
Re-exports
pub use sync::compute_events_hash;pub use sync::decode_sync_envelope;pub use sync::decode_sync_message;pub use sync::discover_dns_sync_peers;pub use sync::encode_sync_envelope_v1;pub use sync::FileReplicationLog;pub use sync::FileSyncCheckpointStore;pub use sync::FileSyncOutbox;pub use sync::FollowerSyncClient;pub use sync::HeartbeatMessage;pub use sync::HttpSyncTransport;pub use sync::InMemoryReplicationLog;pub use sync::InMemorySyncCheckpointStore;pub use sync::InMemorySyncOutbox;pub use sync::LeaderElection;pub use sync::NodeRole;pub use sync::PeerInfo;pub use sync::ReplicationLog;pub use sync::ReplicationSnapshot;pub use sync::ReplicationSnapshotRecord;pub use sync::SyncCheckpointStore;pub use sync::SyncEnvelopeV1;pub use sync::SyncError;pub use sync::SyncMessage;pub use sync::SyncOutbox;pub use sync::SyncPeerAddress;pub use sync::SyncPeerScheme;pub use sync::SyncPushMetrics;pub use sync::SyncReceiveAck;pub use sync::SyncReceiverState;pub use sync::SyncResult;pub use sync::SyncRetryPolicy;pub use sync::SyncStatus;pub use sync::SyncTransport;pub use sync::REPLICATION_LOG_FORMAT_V1;pub use sync::SYNC_CHECKPOINT_FORMAT_V1;pub use sync::SYNC_OUTBOX_FORMAT_V1;pub use sync::SYNC_WIRE_SCHEMA_V1;
Modules
- sync
- Minimal sync contracts and local implementations.
Structs
- Opaque
Content Envelope V1 - Gateway/sync transport metadata for an opaque encrypted content envelope.
- Opaque
Envelope Deduplicator - Bounded in-memory deduplicator keyed by opaque message ID.
- Opaque
Envelope Policy - Transport policy for opaque content envelopes.
Enums
- Opaque
Envelope Decision - Result of opaque transport validation.
Constants
- OPAQUE_
CONTENT_ ENVELOPE_ SCHEMA_ V1 - Schema label for the first opaque content-envelope transport contract.