HttpSyncTransport

Struct HttpSyncTransport 

pub struct HttpSyncTransport { /* private fields */ }
Bounded blocking HTTP client for leader-to-follower sync batches.

Implementations

Source

impl HttpSyncTransport

pub fn new(host: impl Into<String>, port: u16) -> Self

Creates a plain-HTTP transport for host and port.

pub fn with_auth_token(self, token: impl Into<String>) -> Self

Adds a bearer token without exposing it through Debug.

pub fn with_scheme(self, scheme: SyncPeerScheme) -> Self

Selects the HTTP or HTTPS transport scheme.

pub fn with_https(self) -> Self

Selects HTTPS transport.

pub fn with_timeout_ms(self, timeout_ms: u64) -> Self

Sets connect, read, and write deadlines in milliseconds.

pub fn with_timeouts(self, timeouts: HttpTimeouts) -> Self

Sets independent connect, read and write deadlines.

pub fn with_max_response_bytes(self, max_response_bytes: usize) -> Self

Sets the maximum number of response bytes read from a peer.

pub fn with_max_request_body_bytes(self, max_request_body_bytes: usize) -> Self

Sets the maximum encoded request-body size.

pub fn with_source_identity(self, source_identity: CoreIdentity) -> Self

Uses the identity-aware appcore.sync.v1 envelope for outbound batches.

pub fn with_cancellation_token(self, cancellation: CancellationToken) -> Self

Replaces the cooperative cancellation token used by transport I/O.

pub fn cancel(&self)

Cancels active and future transport operations.

pub fn is_cancelled(&self) -> bool

Reports whether cancellation was requested.

pub fn post_sync_events(&self, message: &SyncMessage) -> SyncResult<()>

Posts a batch to /v1/sync/events and requires a 2xx response.