ReplicationLog

Trait ReplicationLog 

pub trait ReplicationLog {
    // Required methods
    fn append(&mut self, record: Vec<u8>) -> SyncResult<usize>;
    fn append_with_sequence(
        &mut self,
        record: Vec<u8>,
        sequence: u64,
    ) -> SyncResult<usize>;
    fn events_since(&self, index: usize) -> SyncResult<Vec<Vec<u8>>>;
    fn last_index(&self) -> SyncResult<usize>;
    fn len(&self) -> SyncResult<usize>;
    fn is_empty(&self) -> SyncResult<bool>;

    // Provided methods
    fn event_at_sequence(&self, _sequence: u64) -> SyncResult<Option<Vec<u8>>> { ... }
    fn create_snapshot(&self) -> SyncResult<ReplicationSnapshot> { ... }
    fn restore_snapshot(
        &mut self,
        _snapshot: &ReplicationSnapshot,
    ) -> SyncResult<()> { ... }
}
Replication log contract.

Required Methods

fn append(&mut self, record: Vec<u8>) -> SyncResult<usize>

Appends an unsequenced record and returns its one-based log index.

fn append_with_sequence( &mut self, record: Vec<u8>, sequence: u64, ) -> SyncResult<usize>

Idempotently appends record at a source sequence.

fn events_since(&self, index: usize) -> SyncResult<Vec<Vec<u8>>>

Returns payloads after the supplied zero-based log offset.

fn last_index(&self) -> SyncResult<usize>

Returns the one-based final log index, or zero for an empty log.

fn len(&self) -> SyncResult<usize>

Returns the number of records in the log.

fn is_empty(&self) -> SyncResult<bool>

Reports whether the log contains no records.

Provided Methods

fn event_at_sequence(&self, _sequence: u64) -> SyncResult<Option<Vec<u8>>>

Returns the payload at a source sequence when sequence lookup is supported.

fn create_snapshot(&self) -> SyncResult<ReplicationSnapshot>

Creates a validated portable snapshot when supported.

fn restore_snapshot( &mut self, _snapshot: &ReplicationSnapshot, ) -> SyncResult<()>

Atomically replaces log contents from a validated snapshot when supported.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors